@@ -71,7 +71,7 @@ mem_stats (void)
 {
   static char buf[128];
 
-  sprintf (buf, "mallocs:%i callocs:%i strdups:%i dups:%i allocs:%i frees:%i reallocs:%i\t|",
+  snprintf (buf, sizeof (buf), "mallocs:%i callocs:%i strdups:%i dups:%i allocs:%i frees:%i reallocs:%i\t|",
            mallocs, callocs, strdups, dups, mallocs + callocs + strdups + dups, frees, reallocs);
   return buf;
 }
@@ -84,16 +84,19 @@ functions_sanity (void)
   if (first_malloc_used != malloc_f ||
       first_free_used != free_f)
     {
+      static int displayed = 0;
+
       if (first_malloc_used == NULL)
         {
           first_malloc_used = malloc_f;
           first_free_used   = free_f;
         }
-      else
+      else if (!displayed)
         {
           fprintf (stderr, "HMM....\nSomething strange is happening,\n%s function pointer changing between invocations in babl.\n",
                    first_malloc_used == malloc_f ? "free" :
                    (first_free_used == free_f ? "malloc" : "malloc and free"));
+          displayed = 1;
         }
     }
 }
@@ -108,8 +111,6 @@ babl_malloc (size_t size)
   char *ret;
   int  offset;
 
-  babl_assert (size);
-
   functions_sanity ();
   ret = malloc_f (BABL_ALLOC + BABL_ALIGN + size);
   if (!ret)
