@@ -19,8 +19,7 @@
 #include "config.h"
 #include <stdlib.h>
 
-#include "babl-classes.h"
-#include "babl.h"
+#include "babl-internal.h"
 #include "babl-ids.h"
 #include "math.h"
 #include "babl-base.h"
@@ -43,25 +42,31 @@ components (void)
 {
   babl_component_new (
     "Y",
-    "id", BABL_LUMINANCE,
+    "id", BABL_GRAY_LINEAR,
     "luma",
     NULL);
 
   babl_component_new (
     "Ya",
-    "id", BABL_LUMINANCE_MUL_ALPHA,
+    "id", BABL_GRAY_LINEAR_MUL_ALPHA,
     "luma",
     NULL);
 
   babl_component_new (
     "Y'",
-    "id", BABL_LUMA,
+    "id", BABL_GRAY_NONLINEAR,
     "luma",
     NULL);
 
   babl_component_new (
     "Y'a",
-    "id", BABL_LUMA_MUL_ALPHA,
+    "id", BABL_GRAY_NONLINEAR_MUL_ALPHA,
+    "luma",
+    NULL);
+
+  babl_component_new (
+    "Y~",
+    "id", BABL_GRAY_PERCEPTUAL,
     "luma",
     NULL);
 }
@@ -71,42 +76,52 @@ models (void)
 {
   babl_model_new (
     "id", BABL_GRAY,
-    babl_component_from_id (BABL_LUMINANCE),
+    babl_component_from_id (BABL_GRAY_LINEAR),
     NULL);
 
 
   babl_model_new (
     "id", BABL_GRAY_ALPHA,
-    babl_component_from_id (BABL_LUMINANCE),
+    babl_component_from_id (BABL_GRAY_LINEAR),
     babl_component_from_id (BABL_ALPHA),
     NULL);
 
   babl_model_new (
     "id", BABL_GRAY_ALPHA_PREMULTIPLIED,
-    babl_component_from_id (BABL_LUMINANCE_MUL_ALPHA),
-    babl_component_from_id (BABL_ALPHA),
-    NULL);
-
-
-  babl_model_new (
-    "id", BABL_GRAY_GAMMA_2_2,
-    babl_component_from_id (BABL_LUMA),
-    NULL);
-
-  babl_model_new (
-    "id", BABL_GRAY_GAMMA_2_2_ALPHA,
-    babl_component_from_id (BABL_LUMA),
+    babl_component_from_id (BABL_GRAY_LINEAR_MUL_ALPHA),
     babl_component_from_id (BABL_ALPHA),
     NULL);
 
   babl_model_new (
-    "id", BABL_GRAY_GAMMA_2_2_ALPHA_PREMULTIPLIED,
-    babl_component_from_id (BABL_LUMA_MUL_ALPHA),
+    "id", BABL_MODEL_GRAY_NONLINEAR,
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
+    NULL);
+
+  babl_model_new (
+    "id", BABL_MODEL_GRAY_NONLINEAR_ALPHA,
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
     babl_component_from_id (BABL_ALPHA),
     NULL);
+
+  babl_model_new (
+    "id", BABL_MODEL_GRAY_NONLINEAR_ALPHA_PREMULTIPLIED,
+    babl_component_from_id (BABL_GRAY_NONLINEAR_MUL_ALPHA),
+    babl_component_from_id (BABL_ALPHA),
+    NULL);
+
+  babl_model_new (
+    "id", BABL_MODEL_GRAY_PERCEPTUAL,
+    babl_component_from_id (BABL_GRAY_PERCEPTUAL),
+    NULL);
+
+  babl_model_new (
+    "id", BABL_MODEL_GRAY_PERCEPTUAL_ALPHA,
+    babl_component_from_id (BABL_GRAY_PERCEPTUAL),
+    babl_component_from_id (BABL_ALPHA),
+    NULL);
+
 }
 
-
 static void
 rgba_to_graya (Babl *conversion,
                char *src,
@@ -171,15 +186,17 @@ rgba_to_gray (Babl *conversion,
     }
 }
 
+static const Babl *perceptual_trc = NULL;
+
 static void
-rgb_to_gray_2_2 (Babl  *conversion,
-                 int    src_bands,
-                 char **src,
-                 int   *src_pitch,
-                 int    dst_bands,
-                 char **dst,
-                 int   *dst_pitch,
-                 long   n)
+rgb_to_gray_nonlinear (Babl  *conversion,
+                       int    src_bands,
+                       char **src,
+                       int   *src_pitch,
+                       int    dst_bands,
+                       char **dst,
+                       int   *dst_pitch,
+                       long   n)
 {
   const Babl *space = babl_conversion_get_destination_space (conversion);
   const Babl *trc = space->space.trc[0];
@@ -201,7 +218,7 @@ rgb_to_gray_2_2 (Babl  *conversion,
       else
         alpha = 1.0;
 
-      luminance = red   * RGB_LUMINANCE_RED +    // XXX: should be taken from BablSpace
+      luminance = red   * RGB_LUMINANCE_RED +
                   green * RGB_LUMINANCE_GREEN +
                   blue  * RGB_LUMINANCE_BLUE;
       *(double *) dst[0] = babl_trc_from_linear (trc, luminance);
@@ -215,14 +232,14 @@ rgb_to_gray_2_2 (Babl  *conversion,
 
 
 static void
-gray_2_2_to_rgb (Babl *conversion,
-                 int    src_bands,
-                 char **src,
-                 int   *src_pitch,
-                 int    dst_bands,
-                 char **dst,
-                 int   *dst_pitch,
-                 long   n)
+gray_nonlinear_to_rgb (Babl *conversion,
+                       int    src_bands,
+                       char **src,
+                       int   *src_pitch,
+                       int    dst_bands,
+                       char **dst,
+                       int   *dst_pitch,
+                       long   n)
 {
   const Babl *space = babl_conversion_get_source_space (conversion);
   const Babl *trc = space->space.trc[0];
@@ -254,6 +271,88 @@ gray_2_2_to_rgb (Babl *conversion,
     }
 }
 
+static void
+rgb_to_gray_perceptual (Babl  *conversion,
+                        int    src_bands,
+                        char **src,
+                        int   *src_pitch,
+                        int    dst_bands,
+                        char **dst,
+                        int   *dst_pitch,
+                        long   n)
+{
+  const Babl *space = babl_conversion_get_destination_space (conversion);
+  const Babl *trc = perceptual_trc;
+  double RGB_LUMINANCE_RED   = space->space.RGBtoXYZ[3];
+  double RGB_LUMINANCE_GREEN = space->space.RGBtoXYZ[4];
+  double RGB_LUMINANCE_BLUE  = space->space.RGBtoXYZ[5];
+
+  BABL_PLANAR_SANITY
+  while (n--)
+    {
+      double red, green, blue;
+      double luminance, alpha;
+
+      red   = *(double *) src[0];
+      green = *(double *) src[1];
+      blue  = *(double *) src[2];
+      if (src_bands > 3)
+        alpha = *(double *) src[3];
+      else
+        alpha = 1.0;
+
+      luminance = red   * RGB_LUMINANCE_RED +
+                  green * RGB_LUMINANCE_GREEN +
+                  blue  * RGB_LUMINANCE_BLUE;
+      *(double *) dst[0] = babl_trc_from_linear (trc, luminance);
+
+      if (dst_bands == 2)
+        *(double *) dst[1] = alpha;
+
+      BABL_PLANAR_STEP
+    }
+}
+
+static void
+gray_perceptual_to_rgb (Babl *conversion,
+                        int    src_bands,
+                        char **src,
+                        int   *src_pitch,
+                        int    dst_bands,
+                        char **dst,
+                        int   *dst_pitch,
+                        long   n)
+{
+  const Babl *trc = perceptual_trc;
+
+  BABL_PLANAR_SANITY
+  while (n--)
+    {
+      double luminance;
+      double red, green, blue;
+      double alpha;
+
+      luminance = babl_trc_to_linear (trc, *(double *) src[0]);
+      red       = luminance;
+      green     = luminance;
+      blue      = luminance;
+      if (src_bands > 1)
+        alpha = *(double *) src[1];
+      else
+        alpha = 1.0;
+
+      *(double *) dst[0] = red;
+      *(double *) dst[1] = green;
+      *(double *) dst[2] = blue;
+
+      if (dst_bands > 3)
+        *(double *) dst[3] = alpha;
+
+      BABL_PLANAR_STEP
+    }
+}
+
+
 static void
 graya_to_rgba (Babl *conversion,
                char *src,
@@ -449,7 +548,7 @@ premultiplied_to_non_premultiplied (Babl  *conversion,
 }
 
 static void
-rgba2gray_gamma_2_2_premultiplied (Babl *conversion,
+rgba2gray_nonlinear_premultiplied (Babl *conversion,
                                    char *src,
                                    char *dst,
                                    long  n)
@@ -485,7 +584,7 @@ rgba2gray_gamma_2_2_premultiplied (Babl *conversion,
 
 
 static void
-gray_gamma_2_2_premultiplied2rgba (Babl *conversion,
+gray_nonlinear_premultiplied2rgba (Babl *conversion,
                                    char *src,
                                    char *dst,
                                    long  n)
@@ -516,53 +615,84 @@ gray_gamma_2_2_premultiplied2rgba (Babl *conversion,
     }
 }
 
-
 static void
 conversions (void)
 {
+  perceptual_trc = babl_trc ("sRGB");
   babl_conversion_new (
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2),
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR),
     babl_model_from_id (BABL_RGBA),
-    "planar", gray_2_2_to_rgb,
+    "planar", gray_nonlinear_to_rgb,
     NULL
   );
 
   babl_conversion_new (
     babl_model_from_id (BABL_RGBA),
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2),
-    "planar", rgb_to_gray_2_2,
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR),
+    "planar", rgb_to_gray_nonlinear,
     NULL
   );
 
   babl_conversion_new (
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2_ALPHA),
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR_ALPHA),
     babl_model_from_id (BABL_RGBA),
-    "planar", gray_2_2_to_rgb,
+    "planar", gray_nonlinear_to_rgb,
     NULL
   );
 
   babl_conversion_new (
     babl_model_from_id (BABL_RGBA),
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2_ALPHA),
-    "planar", rgb_to_gray_2_2,
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR_ALPHA),
+    "planar", rgb_to_gray_nonlinear,
     NULL
   );
 
 
   babl_conversion_new (
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2_ALPHA_PREMULTIPLIED),
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR_ALPHA_PREMULTIPLIED),
     babl_model_from_id (BABL_RGBA),
-    "linear", gray_gamma_2_2_premultiplied2rgba,
+    "linear", gray_nonlinear_premultiplied2rgba,
     NULL
   );
 
   babl_conversion_new (
     babl_model_from_id (BABL_RGBA),
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2_ALPHA_PREMULTIPLIED),
-    "linear", rgba2gray_gamma_2_2_premultiplied,
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR_ALPHA_PREMULTIPLIED),
+    "linear", rgba2gray_nonlinear_premultiplied,
     NULL
   );
 
+
+
+  babl_conversion_new (
+    babl_model_from_id (BABL_MODEL_GRAY_PERCEPTUAL),
+    babl_model_from_id (BABL_RGBA),
+    "planar", gray_perceptual_to_rgb,
+    NULL
+  );
+
+  babl_conversion_new (
+    babl_model_from_id (BABL_RGBA),
+    babl_model_from_id (BABL_MODEL_GRAY_PERCEPTUAL),
+    "planar", rgb_to_gray_perceptual,
+    NULL
+  );
+
+  babl_conversion_new (
+    babl_model_from_id (BABL_MODEL_GRAY_PERCEPTUAL_ALPHA),
+    babl_model_from_id (BABL_RGBA),
+    "planar", gray_perceptual_to_rgb,
+    NULL
+  );
+
+  babl_conversion_new (
+    babl_model_from_id (BABL_RGBA),
+    babl_model_from_id (BABL_MODEL_GRAY_PERCEPTUAL_ALPHA),
+    "planar", rgb_to_gray_perceptual,
+    NULL
+  );
+
+
   babl_conversion_new (
     babl_model_from_id (BABL_GRAY),
     babl_model_from_id (BABL_RGBA),
@@ -626,106 +756,106 @@ formats (void)
   babl_format_new (
     babl_model_from_id (BABL_GRAY_ALPHA),
     babl_type_from_id (BABL_HALF),
-    babl_component_from_id (BABL_LUMINANCE),
+    babl_component_from_id (BABL_GRAY_LINEAR),
     babl_component_from_id (BABL_ALPHA),
     NULL);
   babl_format_new (
     babl_model_from_id (BABL_GRAY_ALPHA_PREMULTIPLIED),
     babl_type_from_id (BABL_HALF),
-    babl_component_from_id (BABL_LUMINANCE_MUL_ALPHA),
+    babl_component_from_id (BABL_GRAY_LINEAR_MUL_ALPHA),
     babl_component_from_id (BABL_ALPHA),
     NULL);
   babl_format_new (
     babl_model_from_id (BABL_GRAY),
     babl_type_from_id (BABL_HALF),
-    babl_component_from_id (BABL_LUMINANCE),
+    babl_component_from_id (BABL_GRAY_LINEAR),
     NULL);
   babl_format_new (
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2_ALPHA),
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR_ALPHA),
     babl_type_from_id (BABL_HALF),
-    babl_component_from_id (BABL_LUMA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
     babl_component_from_id (BABL_ALPHA),
     NULL);
   babl_format_new (
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2_ALPHA_PREMULTIPLIED),
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR_ALPHA_PREMULTIPLIED),
     babl_type_from_id (BABL_HALF),
-    babl_component_from_id (BABL_LUMA_MUL_ALPHA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR_MUL_ALPHA),
     babl_component_from_id (BABL_ALPHA),
     NULL);
   babl_format_new (
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2),
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR),
     babl_type_from_id (BABL_HALF),
-    babl_component_from_id (BABL_LUMA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
     NULL);
   /***********/
 
   babl_format_new (
     babl_model_from_id (BABL_GRAY_ALPHA),
     babl_type ("u15"),
-    babl_component_from_id (BABL_LUMINANCE),
+    babl_component_from_id (BABL_GRAY_LINEAR),
     babl_component_from_id (BABL_ALPHA),
     NULL);
   babl_format_new (
     babl_model_from_id (BABL_GRAY_ALPHA_PREMULTIPLIED),
     babl_type ("u15"),
-    babl_component_from_id (BABL_LUMINANCE_MUL_ALPHA),
+    babl_component_from_id (BABL_GRAY_LINEAR_MUL_ALPHA),
     babl_component_from_id (BABL_ALPHA),
     NULL);
   babl_format_new (
     babl_model_from_id (BABL_GRAY),
     babl_type ("u15"),
-    babl_component_from_id (BABL_LUMINANCE),
+    babl_component_from_id (BABL_GRAY_LINEAR),
     NULL);
   babl_format_new (
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2_ALPHA),
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR_ALPHA),
     babl_type ("u15"),
-    babl_component_from_id (BABL_LUMA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
     babl_component_from_id (BABL_ALPHA),
     NULL);
   babl_format_new (
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2_ALPHA_PREMULTIPLIED),
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR_ALPHA_PREMULTIPLIED),
     babl_type ("u15"),
-    babl_component_from_id (BABL_LUMA_MUL_ALPHA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR_MUL_ALPHA),
     babl_component_from_id (BABL_ALPHA),
     NULL);
   babl_format_new (
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2),
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR),
     babl_type ("u15"),
-    babl_component_from_id (BABL_LUMA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
     NULL);
 
   babl_format_new (
     babl_model_from_id (BABL_GRAY_ALPHA),
     babl_type_from_id (BABL_U32),
-    babl_component_from_id (BABL_LUMINANCE),
+    babl_component_from_id (BABL_GRAY_LINEAR),
     babl_component_from_id (BABL_ALPHA),
     NULL);
   babl_format_new (
     babl_model_from_id (BABL_GRAY_ALPHA_PREMULTIPLIED),
     babl_type_from_id (BABL_U32),
-    babl_component_from_id (BABL_LUMINANCE_MUL_ALPHA),
+    babl_component_from_id (BABL_GRAY_LINEAR_MUL_ALPHA),
     babl_component_from_id (BABL_ALPHA),
     NULL);
   babl_format_new (
     babl_model_from_id (BABL_GRAY),
     babl_type_from_id (BABL_U32),
-    babl_component_from_id (BABL_LUMINANCE),
+    babl_component_from_id (BABL_GRAY_LINEAR),
     NULL);
   babl_format_new (
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2_ALPHA),
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR_ALPHA),
     babl_type_from_id (BABL_U32),
-    babl_component_from_id (BABL_LUMA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
     babl_component_from_id (BABL_ALPHA),
     NULL);
   babl_format_new (
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2_ALPHA_PREMULTIPLIED),
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR_ALPHA_PREMULTIPLIED),
     babl_type_from_id (BABL_U32),
-    babl_component_from_id (BABL_LUMA_MUL_ALPHA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR_MUL_ALPHA),
     babl_component_from_id (BABL_ALPHA),
     NULL);
   babl_format_new (
-    babl_model_from_id (BABL_GRAY_GAMMA_2_2),
+    babl_model_from_id (BABL_MODEL_GRAY_NONLINEAR),
     babl_type_from_id (BABL_U32),
-    babl_component_from_id (BABL_LUMA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
     NULL);
 }
