@@ -63,22 +63,23 @@ models (void)
 {
   babl_model_new (
     "id", BABL_YCBCR,
-    babl_component_from_id (BABL_LUMA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
     babl_component_from_id (BABL_CB),
     babl_component_from_id (BABL_CR),
     NULL);
 
   babl_model_new (
     "id", BABL_YCBCR_ALPHA,
-    babl_component_from_id (BABL_LUMA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
     babl_component_from_id (BABL_CB),
     babl_component_from_id (BABL_CR),
     babl_component_from_id (BABL_ALPHA),
     NULL);
 }
 
-static long
-rgba_to_ycbcra (char *src,
+static void
+rgba_to_ycbcra (BablConversion *conversion,
+                char *src,
                 char *dst,
                 long  n)
 {
@@ -107,12 +108,12 @@ rgba_to_ycbcra (char *src,
       src += sizeof (double) * 4;
       dst += sizeof (double) * 4;
     }
-  return n;
 }
 
 
-static long
-rgba_to_ycbcr (char *src,
+static void
+rgba_to_ycbcr (BablConversion *conversion,
+               char *src,
                char *dst,
                long  n)
 {
@@ -139,11 +140,11 @@ rgba_to_ycbcr (char *src,
       src += sizeof (double) * 4;
       dst += sizeof (double) * 3;
     }
-  return n;
 }
 
-static long
-ycbcra_to_rgba (char *src,
+static void
+ycbcra_to_rgba (BablConversion *conversion,
+                char *src,
                 char *dst,
                 long  n)
 {
@@ -172,12 +173,11 @@ ycbcra_to_rgba (char *src,
       src += sizeof (double) * 4;
       dst += sizeof (double) * 4;
     }
-  return n;
 }
 
-
-static long
-ycbcr_to_rgba (char *src,
+static void
+ycbcr_to_rgba (BablConversion *conversion,
+               char *src,
                char *dst,
                long  n)
 {
@@ -205,7 +205,6 @@ ycbcr_to_rgba (char *src,
       src += sizeof (double) * 3;
       dst += sizeof (double) * 4;
     }
-  return n;
 }
 
 static void
@@ -246,15 +245,17 @@ formats (void)
     babl_model_from_id (BABL_YCBCR),
     babl_type_from_id (BABL_U8_LUMA),
     babl_sampling (1, 1),
-    babl_component_from_id (BABL_LUMA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
     babl_type_from_id (BABL_U8_CHROMA),
     babl_sampling (2, 2),
     babl_component_from_id (BABL_CB),
     babl_sampling (2, 2),
     babl_component_from_id (BABL_CR),
     NULL);
-  return;
 
+/* deactivate these for now */
+if (0)
+{
   babl_format_new (
     "name", "y'cbcr420",
     "id", BABL_YCBCR420,
@@ -262,7 +263,7 @@ formats (void)
     babl_model_from_id (BABL_YCBCR),
     babl_type_from_id (BABL_U8_LUMA),
     babl_sampling (1, 1),
-    babl_component_from_id (BABL_LUMA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
     babl_type_from_id (BABL_U8_CHROMA),
     babl_sampling (2, 2),
     babl_component_from_id (BABL_CB),
@@ -278,7 +279,7 @@ formats (void)
     babl_model_from_id (BABL_YCBCR),
     babl_type_from_id (BABL_U8_LUMA),
     babl_sampling (1, 1),
-    babl_component_from_id (BABL_LUMA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
     babl_type_from_id (BABL_U8_CHROMA),
     babl_sampling (2, 1),
     babl_component_from_id (BABL_CB),
@@ -293,7 +294,7 @@ formats (void)
     babl_model_from_id (BABL_YCBCR),
     babl_type_from_id (BABL_U8_LUMA),
     babl_sampling (1, 1),
-    babl_component_from_id (BABL_LUMA),
+    babl_component_from_id (BABL_GRAY_NONLINEAR),
     babl_type_from_id (BABL_U8_CHROMA),
     babl_sampling (4, 1),
     babl_component_from_id (BABL_CB),
@@ -301,3 +302,4 @@ formats (void)
     babl_component_from_id (BABL_CR),
     NULL);
 }
+}
