@@ -30,8 +30,8 @@
 #include "babl-cpuaccel.h"
 #include "extensions/util.h"
 
-static inline long
-conv_yF_y8 (const float *src, uint8_t *dst, long samples)
+static inline void
+conv_yF_y8 (const Babl *conversion,const float *src, uint8_t *dst, long samples)
 {
   const __v4sf *s_vec;
   __m128i      *d_vec;
@@ -123,33 +123,31 @@ conv_yF_y8 (const float *src, uint8_t *dst, long samples)
 
       n -= 1;
     }
-
-  return samples;
 }
 
-static long
-conv_yaF_ya8 (const float *src, uint8_t *dst, long samples)
+static void
+conv_yaF_ya8 (const Babl *conversion,const float *src, uint8_t *dst, long samples)
 {
-  return conv_yF_y8 (src, dst, samples * 2) / 2;
+  conv_yF_y8 (conversion, src, dst, samples * 2);
 }
 
 
-static long
-conv_rgbF_rgb8 (const float *src, uint8_t *dst, long samples)
+static void
+conv_rgbF_rgb8 (const Babl *conversion,const float *src, uint8_t *dst, long samples)
 {
-  return conv_yF_y8 (src, dst, samples * 3) / 3;
+  conv_yF_y8 (conversion, src, dst, samples * 3);
 }
 
-static long
-conv_rgbaF_rgba8 (const float *src, uint8_t *dst, long samples)
+static void
+conv_rgbaF_rgba8 (const Babl *conversion,const float *src, uint8_t *dst, long samples)
 {
-  return conv_yF_y8 (src, dst, samples * 4) / 4;
+  conv_yF_y8 (conversion, src, dst, samples * 4);
 }
 
-static long
-conv_rgbAF_rgbA8 (const float *src, uint8_t *dst, long samples)
+static void
+conv_rgbAF_rgbA8 (const Babl *conversion,const float *src, uint8_t *dst, long samples)
 {
-  return conv_yF_y8 (src, dst, samples * 4) / 4;
+  conv_yF_y8 (conversion, src, dst, samples * 4);
 }
 
 #endif
